@@ -9,14 +9,28 @@ import sys
 from datetime import datetime
 from typing import List, Optional
 
+from . import __version__
+
+
+def docs():
+    url = f"https://github.com/yellowdog/python-examples/blob/v{__version__}/README.md"
+    print(f"Online documentation for v{__version__}: {url}", flush=True)
+
 
 class CLIParser:
-    def __init__(self):
+    def __init__(self, description: Optional[str] = None):
         """
         Create the argument parser, and parse the command
         line arguments. Argument availability depends on module.
         """
-        parser = argparse.ArgumentParser()
+        parser = argparse.ArgumentParser(description=description)
+
+        parser.add_argument(
+            "--docs",
+            action="store_true",
+            required=False,
+            help="provide a link to the documentation for this version",
+        )
 
         parser.add_argument(
             "--config",
@@ -74,7 +88,7 @@ class CLIParser:
         )
 
         parser.add_argument(
-            "--mustache-substitution",
+            "--mustache",
             "-m",
             type=str,
             required=False,
@@ -270,14 +284,18 @@ class CLIParser:
             )
 
         parser.add_argument(
-            "--stack-trace",
+            "--debug",
             action="store_true",
             required=False,
-            help="print a stack trace on error (for debugging)",
+            help="print a stack trace (etc.) on error",
         )
 
         self.args = parser.parse_args()
 
+        if self.args.docs:
+            docs()
+            exit(0)
+
         # Temporary notification message while we figure out the problem
         # with the use of concurrent futures
         if (
@@ -318,7 +336,7 @@ class CLIParser:
 
     @property
     def mustache_subs(self) -> Optional[List[str]]:
-        return self.args.mustache_substitution
+        return self.args.mustache
 
     @property
     def quiet(self) -> bool:
@@ -393,8 +411,8 @@ class CLIParser:
         return self.args.live_only
 
     @property
-    def stack_trace(self) -> Optional[bool]:
-        return self.args.stack_trace
+    def debug(self) -> Optional[bool]:
+        return self.args.debug
 
     @property
     def directory(self) -> Optional[str]:
@@ -413,7 +431,38 @@ class CLIParser:
         return self.args.recursive
 
 
-ARGS_PARSER = CLIParser()
+def lookup_module_description(module_name: str) -> Optional[str]:
+    """
+    Descriptive string for the module's purpose.
+    """
+    prefix = "YellowDog example utility for "
+    suffix = None
+
+    if "submit" in module_name:
+        suffix = "submitting a Work Requirement"
+    elif "provision" in module_name:
+        suffix = "provisioning a Worker Pool"
+    elif "abort" in module_name:
+        suffix = "aborting Tasks"
+    elif "cancel" in module_name:
+        suffix = "cancelling Work Requirements"
+    elif "download" in module_name:
+        suffix = "downloading objects from the Object Store"
+    elif "delete" in module_name:
+        suffix = "deleting objects in the Object Store"
+    elif "shutdown" in module_name:
+        suffix = "shutting down Worker Pools"
+    elif "terminate" in module_name:
+        suffix = "terminating Compute Requirements"
+    elif "list" in module_name:
+        suffix = "listing entities"
+    elif "instantiate" in module_name:
+        suffix = "provisioning a Compute Requirement"
+
+    return None if suffix is None else prefix + suffix
+
+
+ARGS_PARSER = CLIParser(description=lookup_module_description(sys.argv[0]))
 
 
 if __name__ == "__main__":
